import os
from unittest.mock import Mock

import pytest

from loki.scrapers.pan_115 import Pan115, PathExpect

def test_get_profile():
    from loki.scrapers.tiktok import TikTok
    scraper = TikTok(profile_name="test")
    res = scraper.get_profile_data("jakesing_")
    print(res)